@@ -51,7 +51,10 @@ class Freebox(IPlugin):
 			log.msg("ids  :  %s" % (rs['ids']))
 			if rs['ids'] == idex :
 				log.msg("*************  TROUVé ****************")
-				log.msg("ids sec :  %s" % (rs['ids_sec']))
+				log.msg("idx  :  %s" % (rs['idx']))
+				log.msg("idx sec :  %s" % (rs['idx_sec']))
+				log.msg(" boy  :  %s" % (rs['boy']))
+				
 				if rs['idx_sec'] <> "1":
 					log.msg("*************  'idx_sec'] <> 1 ****************")
 					# séparation de rs['idx'], nombre  
